#!/bin/sh


make_links()
{
  TYPE=$1
  TYPEDIR=$2
  shift; shift;
  XMLFILES=$@
  
  CURBUILDFILE=$BUILDDIR/tmp/$TYPE-build.xml
  cat $BUILDFILE | sed "s|@type@|$TYPE|" > $CURBUILDFILE

  for f in $XMLFILES; do
    PROJECTDIR=$(dirname $f)
    PROJECTNAME=$(ant -Dbasedir=$PROJECTDIR -f $CURBUILDFILE 2>&1 | grep echo | cut --delimiter=' ' -f 7)
    if [ -z $PROJECTNAME ]; then
      if [ ! -e $PROJECTDIR/META-INF/MANIFEST.MF ]; then
        echo "ERROR: could not determine the feature id for $PROJECTDIR"
        exit 1
      fi
      PROJECTNAME=$(grep Bundle-SymbolicName $PROJECTDIR/META-INF/MANIFEST.MF | cut --delimiter=';' -f 1 | cut --delimiter=' ' -f 2)
      if [ -z $PROJECTNAME  ]; then
        echo "ERROR: could not determine the feature id for $PROJECTDIR"
        exit 1
      fi
    fi
    
    echo "  making symlink: $BUILDDIR/$TYPEDIR/$PROJECTNAME -> $PROJECTDIR"
    ln -sf $PROJECTDIR $BUILDDIR/$TYPEDIR/$PROJECTNAME 

  done
}


if [ $# -ne 2 ]; then 
  echo "usage: $0 <path to source dir> <path to build dir>"
  exit 1
fi

if [ ! -d $1 ]; then
  echo "usage: $0 <path to source dir> <path to build dir>"
  exit 1
fi

SOURCEDIR=$1
BUILDDIR=$2

echo "preparing files in $1 for buildfile generation ..."
mkdir -p $BUILDDIR

# make some ant build files to extract the id from the feature.xml, plugin.xml or the fragment.xml
mkdir -p $BUILDDIR/tmp
BUILDFILE=$BUILDDIR/tmp/build.xml

echo "<project default=\"main\">
	<target name=\"main\">
               	<xmlproperty file=\"@type@.xml\" collapseAttributes=\"true\"/>
		<fail unless=\"@type@.id\" message=\"feature.id not set\"/>
               	<echo message=\"\${@type@.id}\" />
        </target>
</project>" > $BUILDFILE

# find the feature.xml, plugin.xml and fragment.xml files
FEATURES=$(find $SOURCEDIR -name feature.xml)
PLUGINS=$(find $SOURCEDIR -name plugin.xml) 
FRAGMENTS=$(find $SOURCEDIR -name fragment.xml) 

# make the directories eclipse is expecting 
echo "  making the 'features' and 'plugins' directories"
mkdir -p $BUILDDIR/features $BUILDDIR/plugins

# make symlinks for the features
make_links feature features $FEATURES

# make the symlinks for plugins
make_links plugin plugins $PLUGINS

# make the symlinks for fragments - they go in the plugins directory as well
make_links fragment plugins $FRAGMENTS

rm -rf $BUILDDIR/tmp
echo done 
